==> magic-7.2.68.tar.bz2: magic-7.2.68/tech/tech.h <==
/*
 * tech.h --
 *
 * Interface to technology module.
 *
 *     ********************************************************************* 
 *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
 *     * Permission to use, copy, modify, and distribute this              * 
 *     * software and its documentation for any purpose and without        * 
 *     * fee is hereby granted, provided that the above copyright          * 
 *     * notice appear in all copies.  The University of California        * 
 *     * makes no representations about the suitability of this            * 
 *     * software for any purpose.  It is provided "as is" without         * 
 *     * express or implied warranty.  Export of this software outside     * 
 *     * of the United States of America may require an export license.    * 
 *     *********************************************************************
 *
 * rcsid "$Header: /ufs/repository/magic/tech/tech.h,v 1.1.1.1 2000/03/29 18:35:37 rajit Exp $"
 */

typedef int SectionID;		/* Mask set by TechAddClient */

/* Techfile section status:  needed for switching between extract and */
/* cif styles when only one style is kept in memory at any given time.*/

#define TECH_NOT_LOADED	0
#define TECH_LOADED	1
#define TECH_PENDING   -1

/* The last format version which was included in the file name */
#define TECH_FORMAT_VERSION 27

/* The format version of the tech file currently active */
extern int TechFormatVersion;

/* ----------------- Exported variables and procedures ---------------- */

extern char *TechFileName;	/* Full path and file name of technology file */
extern char *TechDefault;	/* Name of default technology */
extern bool TechOverridesDefault; /* Set TRUE if technology was specified on
				   * the command line.
				   */
extern void TechError(char *, ...);

==> magic-7.3.11.tar.bz2: magic-7.3.11/tech/tech.h <==
/*
 * tech.h --
 *
 * Interface to technology module.
 *
 *     ********************************************************************* 
 *     * Copyright (C) 1985, 1990 Regents of the University of California. * 
 *     * Permission to use, copy, modify, and distribute this              * 
 *     * software and its documentation for any purpose and without        * 
 *     * fee is hereby granted, provided that the above copyright          * 
 *     * notice appear in all copies.  The University of California        * 
 *     * makes no representations about the suitability of this            * 
 *     * software for any purpose.  It is provided "as is" without         * 
 *     * express or implied warranty.  Export of this software outside     * 
 *     * of the United States of America may require an export license.    * 
 *     *********************************************************************
 *
 * rcsid "$Header: /ufs/repository/magic/tech/tech.h,v 1.1.1.1 2000/03/29 18:35:37 rajit Exp $"
 */

typedef int SectionID;		/* Mask set by TechAddClient */

/* Techfile section status:  needed for switching between extract and */
/* cif styles when only one style is kept in memory at any given time.*/

#define TECH_NOT_LOADED	0
#define TECH_LOADED	1
#define TECH_PENDING   -1

/* The last format version which was included in the file name */
#define TECH_FORMAT_VERSION 27

/* The format version of the tech file currently active */
extern int TechFormatVersion;

/* ----------------- Exported variables  ---------------- */

extern char *TechFileName;	/* Full path and file name of technology file */
extern char *TechDefault;	/* Name of default technology */
extern bool TechOverridesDefault; /* Set TRUE if technology was specified on
				   * the command line.
				   */

/* ----------------- Exported procedures ---------------- */

extern void TechError(char *, ...);
extern void TechAddClient();
extern void TechAddAlias();
